@@ -545,7 +545,9 @@ void show_find_and_replace_dialog (void)
     }
 
     ks.fr_dialog = gtk_dialog_new_with_buttons (NULL, GTK_WINDOW (ks.window), GTK_DIALOG_DESTROY_WITH_PARENT, 
-                                                _("_Replace"), 1, _("_Close"), 2, NULL);
+                                                _("_Replace"), 1, 
+                                                // Translation note: the verb "Close".
+                                                _("_Close"), 2, NULL);
     set_header_bar_for_dialog (ks.fr_dialog, _("Find and Replace"));
     gtk_widget_add_events (ks.fr_dialog, GDK_KEY_PRESS_MASK);
     g_signal_connect (G_OBJECT (ks.fr_dialog), "key-press-event", G_CALLBACK (close_window), "<ctrl>H");
