@@ -148,12 +148,11 @@ void push_new_item_on_undo_stack (const gboolean after_save)
                 g_autofree gchar *err_msg = g_strdup_printf (_("<b>Could not remove undo stack item</b> <tt>%1$i</tt> "
                                                                "<b>inside tmp folder</b> <tt>%2$s</tt> <b>!\nError:</b> %3$s\n\n"
                                                                "--- Note ---\n\n"
-                                                               "All undo stack items after the current position are supposed "
-                                                               "to be deleted when a change is applied prior to the latest change, "
-                                                               "i.e. when it is applied from a position within the undo stack.\n"
-                                                               "A new undo stack item '<tt>%4$i</tt>' for this change won't be saved "
-                                                               "so it will not be possible to recall this change by invoking an "
-                                                               "undo or redo action."), 
+                                                               "All undo stack items after the current position must be "
+                                                               "deleted when a change is applied prior to the latest change, "
+                                                               "i.e. from a position within the undo stack.\n"
+                                                               "A new undo stack item '<tt>%4$i</tt>' for this change will not be saved, "
+                                                               "so this change cannot be recalled with undo or redo."), 
                                                              stack_file_cnt, ks.tmp_path, error->message, ks.pos_inside_undo_stack + 1);
 
                 show_errmsg (err_msg);
